Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/get-spec-ptd](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/get-spec-ptd) for the documentation of this CM script.
